#!/usr/bin/env python

import sys
import numpy as np
import pandas as pd
from pymatgen.io.vasp.outputs import Vasprun

if len(sys.argv) > 1:
    vr_path = sys.argv[1]
else:
    vr_path = "vasprun.xml"

vr = Vasprun(vr_path)
# energy(sigma->0) is e_0_energy
# max norm force in eV/A, breaks when less than EDIFFG (=-0.01 here)

df_dict = {"Energy": [], "Max_Norm_Force": []}
for step_dict in vr.ionic_steps:
    df_dict["Energy"].append(step_dict["e_0_energy"])
    forces_array = step_dict["forces"]
    norms_array = np.apply_along_axis(np.linalg.norm, 1, forces_array)
    df_dict["Max_Norm_Force"].append(np.max(norms_array))

df = pd.DataFrame(df_dict)
df.to_json("E_and_F_vs_step_df.json")
